@@ -23,6 +23,9 @@ sub _new {
 	if($method eq 'smtp') {
 		require Tripletail::Sendmail::Smtp;
 		Tripletail::Sendmail::Smtp->_new($group);
+	} elsif($method eq 'sendmail') {
+		require Tripletail::Sendmail::Sendmail;
+		Tripletail::Sendmail::Sendmail->_new($group);
 	} elsif($method eq 'mailqueue') {
 		require Tripletail::Sendmail::MailQueue;
 		Tripletail::Sendmail::MailQueue->_new($group);
@@ -30,7 +33,7 @@ sub _new {
 		require Tripletail::Sendmail::Esmtp;
 		Tripletail::Sendmail::Esmtp->_new($group);
 	} else {
-		die "TL#newSendmail, ini.method was invalid. [$method]\n";
+		die "TL#newSendmail: ini.method was invalid. [$method] (Iniファイルのmethodの指定が不正です)\n";
 	}
 }
 
@@ -48,7 +51,7 @@ sub disconnect {
 
 sub send {
 	# オーバーライドしなければエラー
-	die __PACKAGE__."#send, internal error: this method has to be overridden.\n";
+	die __PACKAGE__."#send: internal error: this method has to be overridden. (内部エラー:このメソッドはオーバーライドされなければなりません)\n";
 }
 
 sub _setLogging {
@@ -74,7 +77,7 @@ sub _getoptSend {
 	};
 
 	if(!defined($data->{data})) {
-		die "$pkg#send, ARG[data] was undef.\n";
+		die "$pkg#send: arg[data] is not defined. (dataが指定されていません)\n";
 	}
 
 	if(!defined($data->{from}) || !defined($data->{rcpt})) {
@@ -99,10 +102,10 @@ sub _getoptSend {
 	}
 
 	if(!defined($data->{from})) {
-		die "$pkg#send, ARG[from] was undef and not readable from the data.\n";
+		die "$pkg#send: arg[from] is undef and not readable from the data. (fromが指定されておらず、dataからも推測できません)\n";
 	}
 	if(!defined($data->{rcpt})) {
-		die "$pkg#send, ARG[rcpt] was undef and not readable from the data.\n";
+		die "$pkg#send: arg[rcpt] is undef and not readable from the data. (rcptが指定されておらず、dataからも推測できません)\n";
 	}
 
 	if(ref($data->{rcpt}) ne 'ARRAY') {
@@ -187,7 +190,7 @@ sendメソッドを使用した後は、disconnectしなければならない。
   method = smtp
 
 送信メソッドを指定する。省略可能。
-指定可能なメソッドはsmtp、mailqueue、 esmtp の３種類。
+指定可能なメソッドはsmtp、sendmail、mailqueue、 esmtp の３種類。
 
 デフォルトはsmtp。
 
@@ -214,6 +217,8 @@ sendメソッドを使用した後は、disconnectしなければならない。
 
 =item L<Tripletail::Sendmail::Smtp> - SMTP送信
 
+=item L<Tripletail::Sendmail::Sendmail> - Sendmail送信
+
 =item L<Tripletail::Sendmail::MailQueue> - Lib7用メールキュー
 
 =item L<Tripletail::Sendmail::Esmtp> - Forcast esmtp
