@@ -40,7 +40,7 @@ sub setATarget {
 	my $target = shift;
 
 	if(ref($target)) {
-		die __PACKAGE__."#setATarget, ARG[1] was a Ref. [$target]\n";
+		die __PACKAGE__."#setATarget: arg[1] is a Ref. [$target] (第1引数がリファレンスです)\n";
 	}
 
 	$this->{target} = $target;
@@ -52,9 +52,9 @@ sub setAllowTag {
 	my $list = shift;
 
 	if(!defined($list)) {
-		die __PACKAGE__."#setAllowTag, ARG[1] was undef.\n";
+		die __PACKAGE__."#setAllowTag: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($list)) {
-		die __PACKAGE__."#setAllowTag, ARG[1] was a Ref. [$list]\n";
+		die __PACKAGE__."#setAllowTag: arg[1] is a Ref. [$list] (第1引数がリファレンスです)\n";
 	}
 
 	%{$this->{allowed}} = ();
@@ -66,9 +66,9 @@ sub addAllowTag {
 	my $list = shift;
 
 	if(!defined($list)) {
-		die __PACKAGE__."#addAllowTag, ARG[1] was undef.\n";
+		die __PACKAGE__."#addAllowTag: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($list)) {
-		die __PACKAGE__."#addAllowTag, ARG[1] was a Ref. [$list]\n";
+		die __PACKAGE__."#addAllowTag: arg[1] is a Ref. [$list] (第1引数がリファレンスです)\n";
 	}
 
 	while($list =~ s/([:;!])(\w+)([^:;\s]*)//) {
@@ -113,7 +113,7 @@ sub setAutoLink {
 	my $flag = shift;
 
 	if(ref($flag)) {
-		die __PACKAGE__."#setAutoLink, ARG[1] was a Ref. [$flag]\n";
+		die __PACKAGE__."#setAutoLink: arg[1] is a Ref. [$flag] (第1引数がリファレンスです)\n";
 	}
 
 	$this->{autolink} = $flag;
@@ -125,11 +125,11 @@ sub setTagBreak {
 	my $type = shift;
 
 	if(!defined($type)) {
-		die __PACKAGE__."#setTagBreak, ARG[1] was undef.\n";
+		die __PACKAGE__."#setTagBreak: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($type)) {
-		die __PACKAGE__."#setTagBreak, ARG[1] was a Ref. [$type]\n";
+		die __PACKAGE__."#setTagBreak: arg[1] is a Ref. [$type] (第1引数がリファレンスです)\n";
 	} elsif($type ne 'line' && $type ne 'block' && $type ne 'none') {
-		die __PACKAGE__."#setTagBreak, invalid tag-break type: [$type]\n";
+		die __PACKAGE__."#setTagBreak: invalid tag-break type: [$type] (TagBreakの指定が不正です)\n";
 	}
 
 	$this->{tagbreak} = $type;
@@ -141,9 +141,9 @@ sub check {
 	my $html = shift;
 
 	if(!defined($html)) {
-		die __PACKAGE__."#check, ARG[1] was undef.\n";
+		die __PACKAGE__."#check: arg[1] is not defined. (第1引数が指定されていません)\n";
 	} elsif(ref($html)) {
-		die __PACKAGE__."#check, ARG[1] was a Ref. [$html]\n";
+		die __PACKAGE__."#check: arg[1] is a Ref. [$html] (第1引数がリファレンスです)\n";
 	}
 
 	my $filter = $TL->newHtmlFilter(
